%define lib_major       5
%define lib_name        %mklibname link-grammar %{lib_major}
%define develname	%mklibname link-grammar -d

%bcond_without python3

Summary:	A syntactic parser of English
Name:		link-grammar
Version:	5.12.5
Release:	%mkrel 1
Group:		Office/Utilities
License:	BSD-like
URL:		https://opencog.github.io/link-grammar-website/
Source0:	https://www.gnucash.org/link-grammar/downloads/%{version}/%{name}-%{version}.tar.gz
%if %{with python3}
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
%endif
BuildRequires:	java-devel
BuildRequires:	java-openjdk-headless
BuildRequires:	m4
BuildRequires:	ant
BuildRequires:	swig
BuildRequires:	flex
BuildRequires:	graphviz
BuildRequires:	autoconf-archive
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(hunspell)
BuildRequires:	pkgconfig(libedit)
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(sqlite3)

%description
The Link Grammar Parser is a syntactic parser of English, based
on link grammar, an original theory of English syntax. Given a
sentence, the system assigns to it a syntactic structure, which
consists of a set of labeled links connecting pairs of words.
The parser also produces a "constituent" representation of a
sentence (showing noun phrases, verb phrases, etc.).

%package -n %{lib_name}
Summary:	A syntactic parser of English
Group:		System/Libraries

%description -n %{lib_name}
The Link Grammar Parser is a syntactic parser of English, based
on link grammar, an original theory of English syntax. Given a
sentence, the system assigns to it a syntactic structure, which
consists of a set of labeled links connecting pairs of words.
The parser also produces a "constituent" representation of a
sentence (showing noun phrases, verb phrases, etc.).

%package -n %{develname}
Summary:	Support files necessary to compile applications with link-grammar
Group:		Development/C
Requires:	%{lib_name} = %{version}
Requires:	link-grammar
Provides:	link-grammar-devel = %{version}-%{release}

%description -n %{develname}
Libraries and header files necessary to compile applications using
link-grammar.

%package -n python3-%{name}
Summary:        Python 3 files for link-grammar
Group:          Development/Python
Requires:       %{lib_name} = %{version}
Requires:       link-grammar
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python 3 files for link-grammar.

%package -n %{name}-java
Summary:        Java bindings for link-grammar
Group:          Development/Java
Requires:       %{lib_name} = %{version}
Requires:       link-grammar

%description -n %{name}-java
Java bindings for link-grammar.

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--with-hunspell-dictdir=/usr/share/hunspell \
%if %{with python3}
	PYTHON=%{__python3} \
	--enable-python-bindings
%else
	--disable-python-bindings
%endif
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files
%doc README*
%license LICENSE
%{_bindir}/*
%{_datadir}/link-grammar/
%{_mandir}/man1/*

%files -n %{name}-java
%{_datadir}/java/*

%files -n %{lib_name}
%{_libdir}/lib*.so.%{lib_major}{,.*}

%files -n %{develname}
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/link-grammar.pc
%{_includedir}/link-grammar/

%if %{with python3}
%files -n python3-%{name}
%{python3_sitelib}/linkgrammar.pth
%{python3_sitelib}/linkgrammar/
%{python3_sitearch}/linkgrammar/
%endif


%changelog
* Mon May 19 2025 ns80 <ns80> 5.12.5-1.mga10
+ Revision: 2184785
- new version 5.12.5

* Tue Mar 04 2025 wally <wally> 5.12.4-2.mga10
+ Revision: 2160386
- rebuild for python3.13

* Tue May 21 2024 daviddavid <daviddavid> 5.12.4-1.mga10
+ Revision: 2065800
- new version: 5.12.4
- re-enable properly python3 bindings
- enable hunspell support

* Sun Oct 09 2022 neoclust <neoclust> 5.11.0-1.mga9
+ Revision: 1895921
- New version 5.11.0

* Thu Mar 31 2022 umeabot <umeabot> 5.10.2-2.mga9
+ Revision: 1837177
- Mageia 9 Mass Rebuild

* Thu Jan 27 2022 mrambo3501 <mrambo3501> 5.10.2-1.mga9
+ Revision: 1770059
- version 5.10.2
- delete Patch0 applied upstream

* Sun Mar 28 2021 daviddavid <daviddavid> 5.7.0-4.mga9
+ Revision: 1711472
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 5.7.0-3.mga8
+ Revision: 1533701
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 23 2019 wally <wally> 5.7.0-2.mga8
+ Revision: 1444985
- add patch to fix python3 binding build with swig >= 4.0.0

* Sun Sep 22 2019 wally <wally> 5.7.0-1.mga8
+ Revision: 1444659
- new version 5.7.0
- disable python bindings for now (build fails with swig >= 4.0.0)
- drop python2 support

* Wed Jan 09 2019 daviddavid <daviddavid> 5.4.4-3.mga7
+ Revision: 1353097
- rebuild for new Python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 5.4.4-2.mga7
+ Revision: 1299308
- Mageia 7 Mass Rebuild

* Wed Apr 04 2018 kekepower <kekepower> 5.4.4-1.mga7
+ Revision: 1215143
- Update to version 5.4.4
- Created python packages
- Created java package
- Fixed file lists

* Sat Feb 06 2016 umeabot <umeabot> 4.2.5-8.mga6
+ Revision: 941266
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.2.5-7.mga5
+ Revision: 741400
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.5-6.mga5
+ Revision: 681944
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 4.2.5-5.mga4
+ Revision: 521091
- Mageia 4 Mass Rebuild

* Wed Jan 16 2013 fwang <fwang> 4.2.5-4.mga3
+ Revision: 388579
- update rpm group
- unzip patch
- cleanup spec
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Feb 25 2011 ennael <ennael> 4.2.5-2.mga1
+ Revision: 60012
- add patch for error.c
- fix build
- revert and autoreconf
- fix libtool error
- clean spec file
- imported package link-grammar
+ rtp <rtp>
- fix autoreconf line


* Mon Jun 09 2008 Pixel <pixel@mandriva.com> 4.2.5-2mdv2009.0
+ Revision: 217192
- do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
- normalize call to ldconfig in %%post/%%postun

* Tue Mar 25 2008 Emmanuel Andry <eandry@mandriva.org> 4.2.5-2mdv2008.1
+ Revision: 189872
- Fix groups
- protect major

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 13 2007 Jérôme Soyer <saispo@mandriva.org> 4.2.5-1mdv2008.1
+ Revision: 108495
- New release 4.2.4

* Wed Sep 05 2007 Jérôme Soyer <saispo@mandriva.org> 4.2.4-1mdv2008.0
+ Revision: 80232
- New release 4.2.4
- Import link-grammar




* Sat Apr 15 2006 Jerome Soyer <saispo@mandriva.org> 4.2.2-1mdk
- 4.2.2

* Thu Aug 04 2005 Marcel Pol <mpol@mandriva.org> 4.1.3-1mdk
- 4.1.3

* Tue Jul 26 2005 Marcel Pol <mpol@mandriva.org> 4.1.2-0.20050726cvs.2mdk
- fix description and summary (Gaetan Lehmann)
- fix license

* Tue Jul 26 2005 Marcel Pol <mpol@mandriva.org> 4.1.2-0.20050726cvs.1mdk
- cvs release of 4.1.2-20050726cvs
- buildrequires automake1.9
- P1, run versioned automake and aclocal

* Tue May 17 2005 Marcel Pol <mpol@mandriva.org> 4.1.1-1mdk
- Initial version
